@@ -42,6 +42,11 @@ def testrunner(options, args):
     else:
         options.support_zope28 = False
 
+    if CP.has_option(section, 'support_zope213'):
+        options.support_zope213 = CP.getboolean(section, 'support_zope213')
+    else:
+        options.support_zope213 = False
+
     if CP.has_option(section, 'zope_start'):
         options.zope_start = CP.get(section, 'zope_start')
     else:
@@ -268,12 +273,16 @@ def run_tests(sandbox_dir, packages, options):
                                                       runner_options,
                                                       package) 
 
+        elif options.support_zope213:
+            cmd = 'bin/test 1>%s 2>&1 %s -m %s' % (tempf, runner_options, package)
+
         else:
             cmd = 'bin/%s 1>%s 2>&1 test %s -m %s' % (options.zope_start, 
                                                       tempf,
                                                       runner_options,
                                                       package) 
 
+
         # execute the Zope testrunner
         if options.verbose:
             print >>fp, 'Executing %s' % cmd
